Search bandwidth for each univariate kernel smoother such that the
product of these univariate kernel gives a kernel smoother with a
chosen effective degree of freedom (trace of the smoother). The bandwidths are
constrained to give, for each explanatory
variable, a kernel smoother with same trace as the others.
This function is not intended to be used directly.
Usage
departnoyau(df, x, kernel, dftobwitmax, n, p, dfobjectif)
Arguments
df
A numeric vector giving the effective degree of freedom (trace) of the
univariate smoothing matrix for each variable of
x.
x
Matrix of explanatory variables, size n, p.
kernel
Character string which allows to choose between gaussian kernel
("g"), Epanechnikov ("e"), uniform ("u"),
quartic ("q").
dftobwitmax
Specifies the maximum number of iterations
transmitted to uniroot function.
n
Number of rows of data matrix x.
p
Number of columns of data matrix x.
dfobjectif
A numeric vector of length 1 which indicates
the desired effective degree of freedom (trace) of the smoothing
matrix (product kernel smoother) for x.