kernelKx: Evaluates the smoothing matrix at x*

View source: R/kernelKx.R

kernelKxR Documentation

Evaluates the smoothing matrix at x*

Description

The function evaluates the kernel matrix at arbitrary locations x*.

Usage

kernelKx(X,Xetoile=NULL,bx,kernelx="g")

Arguments

X

Matrix of explanatory variables, size n, p.

Xetoile

Matrix of new design points x* at which to predict the response variable, size n*, p. If NULL then Xetoile is equal to X.

bx

The vector of different bandwidths, length p.

kernelx

Character string which allows to choose between gaussian kernel ("g"), Epanechnikov ("e"), uniform ("u"), quartic ("q").

Value

Returns the matrix Kx which i,j entry is equal to

\prod_{k=1}^p K((x_{ik}^*-x_{jk})/h_k)

where K(.) is the chosen kernel.

Author(s)

Pierre-Andre Cornillon, Nicolas Hengartner and Eric Matzner-Lober.

See Also

kernelSx, ibr


ibr documentation built on May 3, 2026, 5:07 p.m.