kernelSx: Evaluates the smoothing matrix at x*

View source: R/kernelSx.R

kernelSxR Documentation

Evaluates the smoothing matrix at x*

Description

The function evaluates the matrix (kernel) smoothing matrix at arbitrary locations x*.

Usage

kernelSx(X,Xetoile=NULL,bx,kernelx="g")

Arguments

X

Matrix of explanatory variables, size n, p.

Xetoile

Matrix of new design points x* at which to predict the response variable, size n*, p. If NULL then Xetoile is equal to X.

bx

The vector of different bandwidths, length p.

kernelx

Character string which allows to choose between gaussian kernel ("g"), Epanechnikov ("e"), uniform ("u"), quartic ("q").

Value

Returns the matrix Sx which i,j entry is equal to

\frac{\prod_{k=1}^p K((x_{ik}^*-x_{jk})/h_k)}{\sum_{j=1}^n \prod_{k=1}^p K((x_{ik}^*-x_{jk})/h_k)}

where K(.) is the chosen kernel.

Author(s)

Pierre-Andre Cornillon, Nicolas Hengartner and Eric Matzner-Lober.

See Also

kernelKx, ibr


ibr documentation built on May 3, 2026, 5:07 p.m.