Learn R Programming

ibr (version 2.0-2)

print.summary.npregress: Printing iterative bias reduction summaries

Description

print method for class “summary.npregress”.

Usage

"print"(x,digits = max(3, getOption("digits") - 3), ...)

Arguments

x
Object of class npregress.
digits
Rounds the values in its first argument to the specified number of significant digits.
...
Further arguments passed to or from other methods.

Value

The function print.summary.npregress prints a list of summary statistics of the fitted iterative bias reduction model given in x.

References

Wand, M. P. and Jones, M. C. (1995). Kernel Smoothing. Chapman and Hall, London.

Examples

Run this code
f <- function(x){sin(5*pi*x)}
n <- 100
x <- runif(n)
z <- f(x)
sigma2 <- 0.05*var(z)
erreur <- rnorm(n,0,sqrt(sigma2))
y <- z+erreur
res <- npregress(x,y,bandwidth=0.02)
summary(res)

Run the code above in your browser using DataLab