Usage
iterchoiceS1cve(X, y, lambda, df, ddlmini, ntest, ntrain,
Kfold, type, npermut, seed, Kmin, Kmax, m, s)
Arguments
X
A numeric matrix of explanatory variables, with n rows
and p columns.
y
A numeric vector of variable to be explained of length n.
lambda
A numeric positive coefficient that governs the
amount of penalty (coefficient lambda).
df
A numeric vector of length 1 which is multiplied by the minimum df of thin
plate splines ; This argument is useless if
lambda is supplied (non null).
ddlmini
The number of eigenvalues equals to 1.
ntest
The number of observations in test set.
ntrain
The number of observations in training set.
Kfold
Either the number of folds or a boolean or NULL.
type
A character string in
random,timeseries,consecutive, interleaved
and give the type of segments.
npermut
The number of random draw (with replacement), used for
type="random".
seed
Controls the seed of random generator
(via set.seed). Kmin
The minimum number of bias correction iterations of the
search grid considered by
the model selection procedure for selecting the optimal number of iterations.
Kmax
The maximum number of bias correction iterations of the
search grid considered by
the model selection procedure for selecting the optimal number of iterations.
m
The order of derivatives for the penalty (for thin plate
splines it is the order). This integer m must verify
2m+2s/d>1, where d is the number of explanatory
variables.
s
The power of weighting function. For thin plate splines
s is equal to 0. This real must be strictly smaller than d/2
(where d is the number of explanatory variables) and must
verify 2m+2s/d. To get pseudo-cubic splines,
choose m=2 and s=(d-1)/2 (See Duchon).