| kernelKx | R Documentation |
The function evaluates the kernel matrix at arbitrary locations x*.
kernelKx(X,Xetoile=NULL,bx,kernelx="g")
X |
Matrix of explanatory variables, size n, p. |
Xetoile |
Matrix of new design points x* at which to predict the
response variable, size n*, p. If |
bx |
The vector of different bandwidths, length |
kernelx |
Character string which allows to choose between gaussian kernel
( |
Returns the matrix Kx which i,j entry is equal to
\prod_{k=1}^p K((x_{ik}^*-x_{jk})/h_k)
where K(.) is the
chosen kernel.
Pierre-Andre Cornillon, Nicolas Hengartner and Eric Matzner-Lober.
kernelSx, ibr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.